summaryrefslogtreecommitdiffstats
path: root/src/inactivity.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/inactivity.h')
-rw-r--r--src/inactivity.h31
1 files changed, 16 insertions, 15 deletions
diff --git a/src/inactivity.h b/src/inactivity.h
index d3fb979..93013db 100644
--- a/src/inactivity.h
+++ b/src/inactivity.h
@@ -22,19 +22,19 @@
/* this is needed to avoid typedef clash with X11
*/
-#ifndef QT_CLEAN_NAMESPACE
-#define QT_CLEAN_NAMESPACE
+#ifndef TQT_CLEAN_NAMESPACE
+#define TQT_CLEAN_NAMESPACE
#endif
// KDE Header
#include <kprocess.h>
// QT Header
-#include <qregexp.h>
-#include <qstring.h>
-#include <qwidget.h>
-#include <qtimer.h>
-#include <qevent.h>
+#include <tqregexp.h>
+#include <tqstring.h>
+#include <tqwidget.h>
+#include <tqtimer.h>
+#include <tqevent.h>
// X11 Header
#include <X11/X.h>
@@ -56,9 +56,10 @@
* \date 2006
*/
-class inactivity : public QWidget
+class inactivity : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
//! default constructor
@@ -67,7 +68,7 @@ public:
~inactivity();
//! to start the monitoring of the X-Server
- void start(int, QStringList);
+ void start(int, TQStringList);
//! to stop the monitoring of the X-Server
void stop();
@@ -79,7 +80,7 @@ signals:
//! signal emited if the with \ref start() set time of inactivity is expired
void inactivityTimeExpired();
//! signal to emit error msg
- void displayErrorMsg( QString );
+ void displayErrorMsg( TQString );
private:
@@ -117,8 +118,8 @@ private:
*/
bool blacklisted_running;
- //! QStringList with blacklisted programs for autosuspend
- QStringList blacklist;
+ //! TQStringList with blacklisted programs for autosuspend
+ TQStringList blacklist;
//! time which must expire befor emit signal for autosuspend
unsigned long timeToInactivity;
@@ -129,20 +130,20 @@ private:
//! if the XServer-has XScreenSaverExtension
int has_XSC_Extension;
//! QTimer intervall for the \ref checkInactivity Timer
/*!
* The time intervall to check for the current status and time of
* userinactivity. The timeslice is currently 30 sec.
*/
static const int CHECK_for_INACTIVITY = 30000;
//! QTimer for check inactivity
/*!
* This timer is used to check the currently status and time of
* userinactivity on the X-Server. The timerinterval is defined trough
* \ref CHECK_for_INACTIVITY .
*/
- QTimer *checkInactivity;
+ TQTimer *checkInactivity;
// -------- FUNCTIONS ------------
@@ -129,20 +130,20 @@ private:
//! if the XServer-has XScreenSaverExtension
int has_XSC_Extension;
- //! QTimer intervall for the \ref checkInactivity Timer
+ //! TQTimer intervall for the \ref checkInactivity Timer
/*!
* The time intervall to check for the current status and time of
@@ -129,20 +130,20 @@ private:
*/
static const int CHECK_for_INACTIVITY = 30000;
- //! QTimer for check inactivity
+ //! TQTimer for check inactivity
/*!
* This timer is used to check the currently status and time of